==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Article &apos;%1&apos; a été ajouté à vos favoris.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+69"/>
        <source>audience</source>
        <translation>Cible</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>Dimension</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>Niveau de détail</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>Perspective</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>Présentation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>Éditeur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>Sujet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1105"/>
        <location filename="../LibraryBrowserInit.js" line="+18"/>
        <source>Library Browser</source>
        <translation>Explorateur de la bibliothèque</translation>
    </message>
    <message>
        <location line="-1097"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Liste</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose Source Folder</source>
        <translation>Choisissez le dossier source</translation>
    </message>
    <message>
        <location line="+652"/>
        <source>Page %1 of %2</source>
        <translation>Page %1 de %2</translation>
    </message>
    <message>
        <location line="+219"/>
        <source>Updating icons...</source>
        <translation>Régénérer icônes...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>Fichier :</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Dossier :</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licence :</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Attribution:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Auteur :</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Mise à jour de l&apos;index :</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Mise à jour de l&apos;index...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Abandonner</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Mise à jour de l&apos;index :</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>Erreur DB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</translation>
    </message>
    <message>
        <location line="+446"/>
        <source>&amp;Insert</source>
        <translation>&amp;Insérer</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Modifier le fichier de script...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Ouvrir fichier &amp;SVG...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Édition...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Fichiers</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Afficher avec %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Retirer des favoris</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;Ajouter aux favoris</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>Régénérer &amp;icône</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Régénérer les icônes</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Préférences</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Synchronisation</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Mettre à jour l&apos;index de recherche au démarrage</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Options d&apos;affichage</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Taille des icônes :</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Mode d&apos;affichage:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Nombre d&apos;éléments affichés
dans les résultats de recherche :</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Sources bibliothèque</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Ajouter...</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Ajouter...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Suppression</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Descendre</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-10"/>
        <source>&amp;Library Browser</source>
        <translation>Explorateur de la &amp;bibliothèque</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Système de fichiers</translation>
    </message>
    <message>
        <location line="+252"/>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Look for:</source>
        <translation>Rechercher :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Réinitialisé</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Update DB from file system</source>
        <translation>Actualiser</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Article &apos;%1&apos; a été ajouté à vos favoris.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+71"/>
        <source>audience</source>
        <translation>Cible</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>Dimension</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>Niveau de détail</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>Perspective</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>Présentation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>Éditeur</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>Sujet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1153"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translation>Explorateur de la bibliothèque</translation>
    </message>
    <message>
        <location line="-1145"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Liste</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translation>Choisissez le dossier source</translation>
    </message>
    <message>
        <location line="+685"/>
        <source>Page %1 of %2</source>
        <translation>Page %1 de %2</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Updating icons...</source>
        <translation>Régénérer icônes...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>Fichier :</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Dossier :</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licence :</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Attribution:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Auteur :</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Mise à jour de l&apos;index :</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Mise à jour de l&apos;index...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Abandonner</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Mise à jour de l&apos;index :</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>Erreur DB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation>Source retiré de la bibliothèque : %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation>Mise à jour de la base de données forcé.</translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translation>&amp;Insérer</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Modifier le fichier de script...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Ouvrir fichier &amp;SVG...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Édition...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Fichiers</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Afficher avec %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Retirer des favoris</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;Ajouter aux favoris</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>Régénérer &amp;icône</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Régénérer les icônes</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Préférences</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Synchronisation</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Mettre à jour l&apos;index de recherche au démarrage</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Options d&apos;affichage</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Taille des icônes :</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Mode d&apos;affichage:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Nombre d&apos;éléments affichés
dans les résultats de recherche :</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Sources bibliothèque</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Ajouter...</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Ajouter...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Suppression</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Descendre</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translation>Explorateur de la &amp;bibliothèque</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Système de fichiers</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <location line="+197"/>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="vanished">Tags</translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Look for:</source>
        <translation>Rechercher :</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Réinitialisé</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+162"/>
        <source>Insert selected item into drawing</source>
        <translation>Insérez élément sélectionné dans le dessin</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translation>Actualiser</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>
